# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import mimetypes
try:
    from urllib.parse import urlparse
except ImportError:
    from urlparse import urlparse

from django.conf import settings
from django.contrib.staticfiles.finders import find
from django.core.files.storage import default_storage
from os.path import basename

import weasyprint


def django_url_fetcher(url):
    # load file:// paths directly from disk
    if url.startswith('file:'):
        mime_type, encoding = mimetypes.guess_type(url)
        url_path = parse.urlparse(url).path
        data = {
            'mime_type': mime_type,
            'encoding': encoding,
            'filename': basename(url_path),
        }

        if url_path.startswith(settings.MEDIA_URL):
            path = url_path.replace(settings.MEDIA_URL, settings.MEDIA_ROOT)
            data['file_obj'] = default_storage.open(path)
            return data

        elif url_path.startswith(settings.STATIC_URL):
            path = url_path.replace(settings.STATIC_URL, '')
            data['file_obj'] = open(find(path), 'rb')
            return data

    # fall back to weasyprint default fetcher
    return weasyprint.default_url_fetcher(url)



import codecs
import os

from setuptools import find_packages, setup

VERSION = '0.5.3'


def read(*parts):
    """
    Build an absolute path from *parts* and and return the contents of the
    resulting file. Assume UTF-8 encoding.
    """
    pwd = os.path.abspath(os.path.dirname(__file__))
    with codecs.open(os.path.join(pwd, *parts), 'rb', 'utf-8') as f:
        return f.read()


setup(
    name='django-weasyprint',
    version=VERSION,
    description='Django WeasyPrint CBV',
    long_description=read('README.rst'),
    url='https://github.com/fdemmer/django-weasyprint',
    download_url='https://github.com/fdemmer/django-weasyprint/archive/v{0}.tar.gz'.format(VERSION),
    author='Florian Demmer',
    author_email='fdemmer@gmail.com',
    license='Apache-2.0',
    classifiers=[
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Framework :: Django",
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
    packages=find_packages(),
    install_requires=[
        "Django>=1.8",
        "WeasyPrint",
    ],
)
